@@ -34,9 +34,12 @@ from stat import *
 from time import time
 from itertools import *
 import logging
-import urllib2
 import fnmatch
 
+# PYCOMPAT
+import six
+from six.moves import zip, filter
+
 try:
     import json
 except ImportError:
@@ -133,8 +136,8 @@ class Plugin(object):
         self.copy_strings = []
         self.collect_cmds = []
 
-        self.soslog = self.commons['soslog'] if self.commons.has_key('soslog') else logging.getLogger('sos')
-        self.proflog = self.commons['proflog'] if self.commons.has_key('proflog') else logging.getLogger('sosprofile')
+        self.soslog = self.commons['soslog'] if 'soslog' in self.commons else logging.getLogger('sos')
+        self.proflog = self.commons['proflog'] if 'proflog' in self.commons else logging.getLogger('sosprofile')
 
         # get the option list into a dictionary
         for opt in self.option_list:
@@ -180,6 +183,9 @@ class Plugin(object):
 
         try:
             for called in self.executed_commands:
+                # was anything collected?
+                if called['file'] == None:
+                    continue
                 if fnmatch.fnmatch(called['exe'], globstr):
                     path = os.path.join(self.commons['cmddir'], called['file'])
                     self.soslog.debug("applying substitution to %s" % path)
@@ -190,9 +196,9 @@ class Plugin(object):
                         self.archive.add_string(result, path)
                     else:
                         replacements = 0
-        except Exception, e:
+        except Exception as e:
             msg = 'regex substitution failed for %s in plugin %s with: "%s"'
-            self.soslog.error(msg % (path, self.name(), e))
+            self.soslog.error(msg % (called['exe'], self.name(), e))
             replacements = 0
         if self.commons['cmdlineopts'].profiler:
             time_passed = time() - start_time
@@ -223,7 +229,7 @@ class Plugin(object):
                 self.archive.add_string(result, srcpath)
             else:
                 replacements = 0
-        except Exception, e:
+        except Exception as e:
             msg = 'regex substitution failed for %s in plugin %s with: "%s"'
             self.soslog.error(msg % (path, self.name(), e))
             replacements = 0
@@ -340,7 +346,7 @@ class Plugin(object):
         try:
             stat = os.stat(srcpath)
             # if not readable(srcpath)
-            if not (stat.st_mode & 0444):
+            if not (stat.st_mode & 0o444):
                 # FIXME: reflect permissions in archive
                 self.archive.add_string("", dest)
             else:
@@ -354,7 +360,7 @@ class Plugin(object):
             if self.commons['cmdlineopts'].profiler:
                 time_passed = time() - start_time
                 self.proflog.debug("copied: %-75s time: %f" % (srcpath, time_passed))
-        except Exception, e:
+        except Exception as e:
             self.soslog.error("Unable to copy %s to %s" % (srcpath, dest))
             self.soslog.error(traceback.format_exc())
 
@@ -373,7 +379,7 @@ class Plugin(object):
 
     def set_option(self, optionname, value):
         '''set the named option to value.'''
-        for name, parms in izip(self.opt_names, self.opt_parms):
+        for name, parms in zip(self.opt_names, self.opt_parms):
             if name == optionname:
                 parms['enabled'] = value
                 return True
@@ -399,13 +405,13 @@ class Plugin(object):
             else:
                 return key == optionname
 
-        for name, parms in izip(self.opt_names, self.opt_parms):
+        for name, parms in zip(self.opt_names, self.opt_parms):
             if _check(name):
                 val = parms['enabled']
                 if val != None:
                     return val
 
-        for key, value in self.commons.get('global_plugin_options', {}).iteritems():
+        for key, value in six.iteritems(self.commons.get('global_plugin_options', {})):
             if _check(key):
                 return value
 
@@ -418,7 +424,7 @@ class Plugin(object):
         option = self.get_option(optionname)
         try:
             opt_list = [opt.strip() for opt in option.split(delimiter)]
-            return filter(None, opt_list)
+            return list(filter(None, opt_list))
         except Exception:
             return default
 
@@ -476,12 +482,21 @@ class Plugin(object):
             if filespec not in self.copy_paths:
                 self.copy_paths.append((filespec, sub))
 
+    def get_command_output(self, prog, timeout=300):
+        (status, output, runtime) = sos_get_command_output(prog, timeout)
+        if status == 124:
+            self.soslog.warning("command '%s' timed out after %ds"
+                    % (prog, timeout))
+        if status == 127:
+            self.soslog.warning("could not run '%s': command not found" % prog)
+        return (status, output, runtime)
+
     def call_ext_prog(self, prog, timeout=300):
         """Execute a command independantly of the output gathering part of
         sosreport.
         """
         # pylint: disable-msg = W0612
-        return sos_get_command_output(prog, timeout)
+        return self.get_command_output(prog, timeout)
 
     def check_ext_prog(self, prog):
         """Execute a command independently of the output gathering part of
@@ -496,12 +511,27 @@ class Plugin(object):
         """Run a program and collect the output"""
         self.collect_cmds.append( (exe, suggest_filename, root_symlink, timeout) )
 
-    def get_cmd_dir(self):
-        """Return a directory into which this module should store
-        collected command output"""
+    def get_cmd_path(self):
+        """Return a path into which this module should store collected
+        command output
+        """
         return os.path.join(self.archive.get_tmp_dir(),
                             'sos_commands', self.name())
 
+    def make_cmd_path(self, path):
+        """Return a string representing an absolute path within this
+        plug-in's command output directory by apending the relative path
+        name 'path'.
+        """
+        return os.path.join(self.get_cmd_path(), path)
+        
+
+    def make_cmd_dirs(self, path):
+        """Recursively create new subdirectories under this plug-in's
+        command output path.
+        """
+        os.makedirs(self.make_cmd_path(path))
+
     def file_grep(self, regexp, *fnames):
         """Returns lines matched in fnames, where fnames can either be
         pathnames to files to grep through or open file objects to grep through
@@ -541,9 +571,8 @@ class Plugin(object):
             start_time = time()
 
         # pylint: disable-msg = W0612
-        status, shout, runtime = sos_get_command_output(exe, timeout=timeout)
+        status, shout, runtime = self.get_command_output(exe, timeout=timeout)
         if (status == 127):
-            self.soslog.debug("could not run '%s': command not found" % exe)
             return None
 
         if suggest_filename:
@@ -588,17 +617,17 @@ class Plugin(object):
             try:
                 self.archive.add_string(string,
                         os.path.join('sos_strings', self.name(), file_name))
-            except Exception, e:
+            except Exception as e:
                 self.soslog.debug("could not create %s, traceback follows: %s"
                         % (file_name, e))
 
-        for progs in izip(self.collect_cmds):
+        for progs in zip(self.collect_cmds):
             prog, suggest_filename, root_symlink, timeout = progs[0]
             self.soslog.debug("collecting output of '%s'" % prog)
             try:
                 self.get_cmd_output_now(prog, suggest_filename,
                         root_symlink, timeout)
-            except Exception, e:
+            except Exception as e:
                 self.soslog.debug("error collecting output of '%s' (%s)"
                         % (prog, e))
 
@@ -620,10 +649,10 @@ class Plugin(object):
         """
         # some files or packages have been specified for this package
         if self.files or self.packages:
-            if isinstance(self.files, basestring):
+            if isinstance(self.files, six.string_types):
                 self.files = [self.files]
 
-            if isinstance(self.packages, basestring):
+            if isinstance(self.packages, six.string_types):
                 self.packages = [self.packages]
 
             return (any(os.path.exists(fname) for fname in self.files) or
