@@ -14,32 +14,17 @@
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
-class Samba(Plugin):
+class Samba(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
     """Samba related information
     """
+    packages = ('samba-common',)
     plugin_name = "samba"
 
     def setup(self):
         self.add_copy_specs([
             "/etc/samba",
             "/var/log/samba/*",])
-        self.add_cmd_output("wbinfo -g")
-        self.add_cmd_output("wbinfo -u")
+        self.add_cmd_output("wbinfo --domain='.' -g")
+        self.add_cmd_output("wbinfo --domain='.' -u")
         self.add_cmd_output("testparm -s -v")
 
-
-class RedHatSamba(Samba, RedHatPlugin):
-    """Samba related information for RedHat based distributions
-    """
-    def setup(self):
-        super(RedHatSamba, self).setup()
-        # FIXME: krb5 specific
-        self.add_copy_specs([
-            "/etc/krb5.conf",
-            "/etc/krb5.keytab"])
-
-class DebianSamba(Samba, DebianPlugin, UbuntuPlugin):
-    """Samba related information for Debian based distributions
-    """
-    def setup(self):
-        super(DebianSamba, self).setup()
